@@ -23,6 +23,7 @@ import org.apache.doris.catalog.MaterializedIndex.IndexState;
 import org.apache.doris.cloud.catalog.CloudPartition;
 import org.apache.doris.common.Config;
 import org.apache.doris.common.FeConstants;
+import org.apache.doris.common.FeMetaVersion;
 import org.apache.doris.common.io.Text;
 import org.apache.doris.rpc.RpcException;
 
@@ -350,6 +351,14 @@ public class Partition extends MetaObject {
 
     @Deprecated
     public static Partition read(DataInput in) throws IOException {
+        if (Env.getCurrentEnvJournalVersion() <= FeMetaVersion.VERSION_129) {
+            // For meta <= 2.1, we should not call EnvFactory.getInstance().createPartition(), because
+            // it will create a new CloudPartition in cloud mode, which is not expected in meta <= 2.1.
+            // This case happens when we restore old doris <= 2.1 to a new cloud doris.
+            Partition partition = new Partition();
+            partition.readFields(in);
+            return partition;
+        }
         Partition partition = EnvFactory.getInstance().createPartition();
         partition.readFields(in);
         return partition;
