@@ -22,7 +22,7 @@ import org.apache.doris.analysis.PartitionNames;
 import org.apache.doris.common.DdlException;
 import org.apache.doris.common.UserException;
 import org.apache.doris.datasource.CatalogProperty;
-import org.apache.doris.datasource.property.constants.HMSProperties;
+import org.apache.doris.datasource.property.metastore.HMSBaseProperties;
 import org.apache.doris.nereids.exceptions.NotSupportedException;
 
 import java.util.Map;
@@ -32,7 +32,7 @@ public class IcebergDLFExternalCatalog extends IcebergExternalCatalog {
     public IcebergDLFExternalCatalog(long catalogId, String name, String resource, Map<String, String> props,
             String comment) {
         super(catalogId, name, comment);
-        props.put(HMSProperties.HIVE_METASTORE_TYPE, "dlf");
+        props.put(HMSBaseProperties.HIVE_METASTORE_TYPE, "dlf");
         catalogProperty = new CatalogProperty(resource, props);
     }
 
