@@ -306,6 +306,7 @@ public class ExportJob implements Writable {
         List<List<Long>> tabletsListPerParallel = splitTablets();
 
         // Each Outfile clause responsible for MAXIMUM_TABLETS_OF_OUTFILE_IN_EXPORT tablets
+        int index = 0;
         for (List<Long> tabletsList : tabletsListPerParallel) {
             // generate LogicalPlan
             LogicalPlan plan = generateOneLogicalPlan(qualifiedTableName, tabletsList,
@@ -313,6 +314,10 @@ public class ExportJob implements Writable {
             // generate  LogicalPlanAdapter
             StatementBase statementBase = generateLogicalPlanAdapter(plan);
             selectStmtPerParallel.add(Optional.of(statementBase));
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Export Job [{}]: parallelism {} tablets: {}", id, index, tabletsList);
+            }
+            index++;
         }
     }
 
@@ -578,13 +583,12 @@ public class ExportJob implements Writable {
         if (format.equals("csv") || format.equals("csv_with_names") || format.equals("csv_with_names_and_types")) {
             outfileProperties.put(OutFileClause.PROP_COLUMN_SEPARATOR, columnSeparator);
             outfileProperties.put(OutFileClause.PROP_LINE_DELIMITER, lineDelimiter);
-        } else {
-            // orc / parquet
-            // compressType == null means outfile will use default compression type
-            if (compressType != null) {
-                outfileProperties.put(ExportCommand.COMPRESS_TYPE, compressType);
-            }
         }
+        // compressType == null means outfile will use default compression type
+        if (compressType != null) {
+            outfileProperties.put(ExportCommand.COMPRESS_TYPE, compressType);
+        }
+
         if (!maxFileSize.isEmpty()) {
             outfileProperties.put(OutFileClause.PROP_MAX_FILE_SIZE, maxFileSize);
         }
