@@ -30,7 +30,7 @@ set -eo pipefail
 build_version_prefix="${DORIS_BUILD_VERSION_PREFIX-doris}"
 build_version_major="${DORIS_BUILD_VERSION_MAJOR-3}"
 build_version_minor="${DORIS_BUILD_VERSION_MINOR-1}"
-build_version_patch="${DORIS_BUILD_VERSION_PATCH-1}"
+build_version_patch="${DORIS_BUILD_VERSION_PATCH-2}"
 build_version_hotfix="${DORIS_BUILD_VERSION_HOTFIX-0}"
 build_version_rc_version="${DORIS_BUILD_VERSION_RC_VERSION-"rc01"}"
 
@@ -42,6 +42,7 @@ if [[ -n "${build_version_rc_version}" ]]; then
     build_version+="-${build_version_rc_version}"
 fi
 
+doris_feature_list="${DORIS_FEATURE_LIST-""}"
 # This version is used to check FeMetaVersion is not changed during release
 build_fe_meta_version=0
 unset LANG
@@ -134,6 +135,7 @@ public class Version {
   public static final int DORIS_BUILD_VERSION_PATCH = ${build_version_patch};
   public static final int DORIS_BUILD_VERSION_HOTFIX = ${build_version_hotfix};
   public static final String DORIS_BUILD_VERSION_RC_VERSION = "${build_version_rc_version}";
+  public static final String DORIS_FEATURE_LIST = "${doris_feature_list}";
 
   public static final String DORIS_BUILD_VERSION = "${build_version}";
   public static final String DORIS_BUILD_HASH = "${build_hash}";
@@ -149,6 +151,7 @@ public class Version {
     System.out.println("doris_build_version_minor: " + DORIS_BUILD_VERSION_MINOR);
     System.out.println("doris_build_version_patch: " + DORIS_BUILD_VERSION_PATCH);
     System.out.println("doris_build_version_rc_version: " + DORIS_BUILD_VERSION_RC_VERSION);
+    System.out.println("doris_feature_list: " + DORIS_FEATURE_LIST);
 
     System.out.println("doris_build_version: " + DORIS_BUILD_VERSION);
     System.out.println("doris_build_hash: " + DORIS_BUILD_HASH);
@@ -202,6 +205,7 @@ namespace doris {
 #define DORIS_BUILD_SHORT_HASH          "${build_short_hash}"
 #define DORIS_BUILD_TIME                "${build_time}"
 #define DORIS_BUILD_INFO                "${build_info}"
+#define DORIS_FEATURE_LIST              "${doris_feature_list}"
 
 } // namespace doris
 
@@ -263,6 +267,7 @@ namespace doris::cloud {
 #define DORIS_CLOUD_BUILD_VERSION_PATCH       ${build_version_patch}
 #define DORIS_CLOUD_BUILD_VERSION_HOTFIX      ${build_version_hotfix}
 #define DORIS_CLOUD_BUILD_VERSION_RC_VERSION  R"(${build_version_rc_version})"
+#define DORIS_CLOUD_FEATURE_LIST              R"(${doris_feature_list})"
 
 #define DORIS_CLOUD_BUILD_VERSION             R"(${build_version})"
 #define DORIS_CLOUD_BUILD_HASH                R"(${build_hash})"
