@@ -20,11 +20,14 @@
 #include <bthread/countdown_event.h>
 
 #include "cloud/cloud_storage_engine.h"
+#include "cloud/cloud_tablet.h"
 #include "cloud/cloud_tablet_mgr.h"
+#include "cloud/cloud_warm_up_manager.h"
 #include "cloud/config.h"
 #include "io/cache/block_file_cache.h"
 #include "io/cache/block_file_cache_downloader.h"
 #include "io/cache/block_file_cache_factory.h"
+#include "util/debug_points.h"
 
 namespace doris {
 
@@ -223,9 +226,27 @@ void CloudInternalServiceImpl::warm_up_rowset(google::protobuf::RpcController* c
             expiration_time = 0;
         }
 
+        if (!tablet->add_rowset_warmup_state(rs_meta, WarmUpTriggerSource::EVENT_DRIVEN)) {
+            LOG(INFO) << "found duplicate warmup task for rowset " << rowset_id.to_string()
+                      << ", skip it";
+            continue;
+        }
+
         for (int64_t segment_id = 0; segment_id < rs_meta.num_segments(); segment_id++) {
             auto segment_size = rs_meta.segment_file_size(segment_id);
-            auto download_done = [=](Status st) {
+            auto download_done = [=, version = rs_meta.version()](Status st) {
+                DBUG_EXECUTE_IF("CloudInternalServiceImpl::warm_up_rowset.download_segment", {
+                    auto sleep_time = dp->param<int>("sleep", 3);
+                    LOG_INFO("[verbose] block download for rowset={}, version={}, sleep={}",
+                             rowset_id.to_string(), version.to_string(), sleep_time);
+                    std::this_thread::sleep_for(std::chrono::seconds(sleep_time));
+                });
+                DBUG_EXECUTE_IF(
+                        "CloudInternalServiceImpl::warm_up_rowset.download_segment.inject_error", {
+                            st = Status::InternalError("injected error");
+                            LOG_INFO("[verbose] inject error, tablet={}, rowset={}, st={}",
+                                     tablet_id, rowset_id.to_string(), st.to_string());
+                        });
                 if (st.ok()) {
                     g_file_cache_event_driven_warm_up_finished_segment_num << 1;
                     g_file_cache_event_driven_warm_up_finished_segment_size << segment_size;
@@ -256,6 +277,12 @@ void CloudInternalServiceImpl::warm_up_rowset(google::protobuf::RpcController* c
                     LOG(WARNING) << "download segment failed, tablet_id: " << tablet_id
                                  << " rowset_id: " << rowset_id.to_string() << ", error: " << st;
                 }
+                if (tablet->complete_rowset_segment_warmup(WarmUpTriggerSource::EVENT_DRIVEN,
+                                                           rowset_id, st, 1, 0)
+                            .trigger_source == WarmUpTriggerSource::EVENT_DRIVEN) {
+                    VLOG_DEBUG << "warmup rowset " << version.to_string() << "("
+                               << rowset_id.to_string() << ") completed";
+                }
                 if (wait) {
                     wait->signal();
                 }
@@ -267,13 +294,10 @@ void CloudInternalServiceImpl::warm_up_rowset(google::protobuf::RpcController* c
                     .offset = 0,
                     .download_size = segment_size,
                     .file_system = storage_resource.value()->fs,
-                    .ctx =
-                            {
-                                    .is_index_data = false,
-                                    .expiration_time = expiration_time,
-                                    .is_dryrun =
-                                            config::enable_reader_dryrun_when_download_file_cache,
-                            },
+                    .ctx = {.is_index_data = false,
+                            .expiration_time = expiration_time,
+                            .is_dryrun = config::enable_reader_dryrun_when_download_file_cache,
+                            .is_warmup = true},
                     .download_done = std::move(download_done),
             };
             g_file_cache_event_driven_warm_up_submitted_segment_num << 1;
@@ -283,9 +307,18 @@ void CloudInternalServiceImpl::warm_up_rowset(google::protobuf::RpcController* c
             }
             _engine.file_cache_block_downloader().submit_download_task(download_meta);
 
-            auto download_inverted_index = [&](std::string index_path, uint64_t idx_size) {
+            auto download_inverted_index = [&, tablet](std::string index_path, uint64_t idx_size) {
                 auto storage_resource = rs_meta.remote_storage_resource();
-                auto download_done = [=](Status st) {
+                auto download_done = [=, version = rs_meta.version()](Status st) {
+                    DBUG_EXECUTE_IF(
+                            "CloudInternalServiceImpl::warm_up_rowset.download_inverted_idx", {
+                                auto sleep_time = dp->param<int>("sleep", 3);
+                                LOG_INFO(
+                                        "[verbose] block download for rowset={}, inverted index "
+                                        "file={}, sleep={}",
+                                        rowset_id.to_string(), index_path, sleep_time);
+                                std::this_thread::sleep_for(std::chrono::seconds(sleep_time));
+                            });
                     if (st.ok()) {
                         g_file_cache_event_driven_warm_up_finished_index_num << 1;
                         g_file_cache_event_driven_warm_up_finished_index_size << idx_size;
@@ -319,6 +352,12 @@ void CloudInternalServiceImpl::warm_up_rowset(google::protobuf::RpcController* c
                                 << "download inverted index failed, tablet_id: " << tablet_id
                                 << " rowset_id: " << rowset_id.to_string() << ", error: " << st;
                     }
+                    if (tablet->complete_rowset_segment_warmup(WarmUpTriggerSource::EVENT_DRIVEN,
+                                                               rowset_id, st, 0, 1)
+                                .trigger_source == WarmUpTriggerSource::EVENT_DRIVEN) {
+                        VLOG_DEBUG << "warmup rowset " << version.to_string() << "("
+                                   << rowset_id.to_string() << ") completed";
+                    }
                     if (wait) {
                         wait->signal();
                     }
@@ -327,18 +366,16 @@ void CloudInternalServiceImpl::warm_up_rowset(google::protobuf::RpcController* c
                         .path = io::Path(index_path),
                         .file_size = static_cast<int64_t>(idx_size),
                         .file_system = storage_resource.value()->fs,
-                        .ctx =
-                                {
-                                        .is_index_data = false, // DORIS-20877
-                                        .expiration_time = expiration_time,
-                                        .is_dryrun = config::
-                                                enable_reader_dryrun_when_download_file_cache,
-                                },
+                        .ctx = {.is_index_data = false, // DORIS-20877
+                                .expiration_time = expiration_time,
+                                .is_dryrun = config::enable_reader_dryrun_when_download_file_cache,
+                                .is_warmup = true},
                         .download_done = std::move(download_done),
                 };
                 g_file_cache_event_driven_warm_up_submitted_index_num << 1;
                 g_file_cache_event_driven_warm_up_submitted_index_size << idx_size;
-
+                tablet->update_rowset_warmup_state_inverted_idx_num(
+                        WarmUpTriggerSource::EVENT_DRIVEN, rowset_id, 1);
                 if (wait) {
                     wait->add_count();
                 }
