@@ -141,7 +141,7 @@ Status CloudSchemaChangeJob::process_alter_tablet(const TAlterTabletReqV2& reque
     if (request.alter_version > 1) {
         // [0-1] is a placeholder rowset, no need to convert
         RETURN_IF_ERROR(_base_tablet->capture_rs_readers({2, start_resp.alter_version()},
-                                                         &rs_splits, false));
+                                                         &rs_splits, CaptureRowsetOps {}));
     }
     Defer defer2 {[&]() {
         _new_tablet->set_alter_version(-1);
