@@ -25,6 +25,7 @@
 #include <tuple>
 
 #include "bvar/bvar.h"
+#include "cloud/cloud_tablet.h"
 #include "cloud/cloud_tablet_mgr.h"
 #include "cloud/config.h"
 #include "common/logging.h"
@@ -40,6 +41,8 @@
 
 namespace doris {
 
+bvar::Adder<uint64_t> g_file_cache_event_driven_warm_up_skipped_rowset_num(
+        "file_cache_event_driven_warm_up_skipped_rowset_num");
 bvar::Adder<uint64_t> g_file_cache_event_driven_warm_up_requested_segment_size(
         "file_cache_event_driven_warm_up_requested_segment_size");
 bvar::Adder<uint64_t> g_file_cache_event_driven_warm_up_requested_segment_num(
@@ -108,7 +111,7 @@ void CloudWarmUpManager::submit_download_tasks(io::Path path, int64_t file_size,
                                                io::FileSystemSPtr file_system,
                                                int64_t expiration_time,
                                                std::shared_ptr<bthread::CountdownEvent> wait,
-                                               bool is_index) {
+                                               bool is_index, std::function<void(Status)> done_cb) {
     if (file_size < 0) {
         auto st = file_system->file_size(path, &file_size);
         if (!st.ok()) [[unlikely]] {
@@ -139,13 +142,12 @@ void CloudWarmUpManager::submit_download_tasks(io::Path path, int64_t file_size,
                 .offset = offset,
                 .download_size = current_chunk_size,
                 .file_system = file_system,
-                .ctx =
-                        {
-                                .expiration_time = expiration_time,
-                                .is_dryrun = config::enable_reader_dryrun_when_download_file_cache,
-                        },
+                .ctx = {.expiration_time = expiration_time,
+                        .is_dryrun = config::enable_reader_dryrun_when_download_file_cache,
+                        .is_warmup = true},
                 .download_done =
-                        [=](Status st) {
+                        [&, done_cb = std::move(done_cb)](Status st) {
+                            if (done_cb) done_cb(st);
                             if (!st) {
                                 LOG_WARNING("Warm up error ").error(st);
                             } else if (is_index) {
@@ -211,26 +213,39 @@ void CloudWarmUpManager::handle_jobs() {
             auto tablet_meta = tablet->tablet_meta();
             auto rs_metas = snapshot_rs_metas(tablet.get());
             for (auto& [_, rs] : rs_metas) {
+                auto storage_resource = rs->remote_storage_resource();
+                if (!storage_resource) {
+                    LOG(WARNING) << storage_resource.error();
+                    continue;
+                }
+
+                int64_t expiration_time =
+                        tablet_meta->ttl_seconds() == 0 || rs->newest_write_timestamp() <= 0
+                                ? 0
+                                : rs->newest_write_timestamp() + tablet_meta->ttl_seconds();
+                if (expiration_time <= UnixSeconds()) {
+                    expiration_time = 0;
+                }
+                if (!tablet->add_rowset_warmup_state(*rs, WarmUpTriggerSource::JOB)) {
+                    LOG(INFO) << "found duplicate warmup task for rowset " << rs->rowset_id()
+                              << ", skip it";
+                    continue;
+                }
                 for (int64_t seg_id = 0; seg_id < rs->num_segments(); seg_id++) {
-                    auto storage_resource = rs->remote_storage_resource();
-                    if (!storage_resource) {
-                        LOG(WARNING) << storage_resource.error();
-                        continue;
-                    }
-
-                    int64_t expiration_time =
-                            tablet_meta->ttl_seconds() == 0 || rs->newest_write_timestamp() <= 0
-                                    ? 0
-                                    : rs->newest_write_timestamp() + tablet_meta->ttl_seconds();
-                    if (expiration_time <= UnixSeconds()) {
-                        expiration_time = 0;
-                    }
-
                     // 1st. download segment files
                     submit_download_tasks(
                             storage_resource.value()->remote_segment_path(*rs, seg_id),
                             rs->segment_file_size(seg_id), storage_resource.value()->fs,
-                            expiration_time, wait);
+                            expiration_time, wait, false, [tablet, rs, seg_id](Status st) {
+                                VLOG_DEBUG << "warmup rowset " << rs->version() << " segment "
+                                           << seg_id << " completed";
+                                if (tablet->complete_rowset_segment_warmup(WarmUpTriggerSource::JOB,
+                                                                           rs->rowset_id(), st, 1,
+                                                                           0)
+                                            .trigger_source == WarmUpTriggerSource::JOB) {
+                                    VLOG_DEBUG << "warmup rowset " << rs->version() << " completed";
+                                }
+                            });
 
                     // 2nd. download inverted index files
                     int64_t file_size = -1;
@@ -252,8 +267,22 @@ void CloudWarmUpManager::handle_jobs() {
                                     }
                                 }
                             }
-                            submit_download_tasks(idx_path, file_size, storage_resource.value()->fs,
-                                                  expiration_time, wait, true);
+                            tablet->update_rowset_warmup_state_inverted_idx_num(
+                                    WarmUpTriggerSource::JOB, rs->rowset_id(), 1);
+                            submit_download_tasks(
+                                    idx_path, file_size, storage_resource.value()->fs,
+                                    expiration_time, wait, true, [=](Status st) {
+                                        VLOG_DEBUG << "warmup rowset " << rs->version()
+                                                   << " segment " << seg_id
+                                                   << "inverted idx:" << idx_path << " completed";
+                                        if (tablet->complete_rowset_segment_warmup(
+                                                          WarmUpTriggerSource::JOB, rs->rowset_id(),
+                                                          st, 0, 1)
+                                                    .trigger_source == WarmUpTriggerSource::JOB) {
+                                            VLOG_DEBUG << "warmup rowset " << rs->version()
+                                                       << " completed";
+                                        }
+                                    });
                         }
                     } else {
                         if (schema_ptr->has_inverted_index()) {
@@ -261,8 +290,22 @@ void CloudWarmUpManager::handle_jobs() {
                                     storage_resource.value()->remote_idx_v2_path(*rs, seg_id);
                             file_size = idx_file_info.has_index_size() ? idx_file_info.index_size()
                                                                        : -1;
-                            submit_download_tasks(idx_path, file_size, storage_resource.value()->fs,
-                                                  expiration_time, wait, true);
+                            tablet->update_rowset_warmup_state_inverted_idx_num(
+                                    WarmUpTriggerSource::JOB, rs->rowset_id(), 1);
+                            submit_download_tasks(
+                                    idx_path, file_size, storage_resource.value()->fs,
+                                    expiration_time, wait, true, [=](Status st) {
+                                        VLOG_DEBUG << "warmup rowset " << rs->version()
+                                                   << " segment " << seg_id
+                                                   << "inverted idx:" << idx_path << " completed";
+                                        if (tablet->complete_rowset_segment_warmup(
+                                                          WarmUpTriggerSource::JOB, rs->rowset_id(),
+                                                          st, 0, 1)
+                                                    .trigger_source == WarmUpTriggerSource::JOB) {
+                                            VLOG_DEBUG << "warmup rowset " << rs->version()
+                                                       << " completed";
+                                        }
+                                    });
                         }
                     }
                 }
@@ -507,6 +550,7 @@ void CloudWarmUpManager::warm_up_rowset(RowsetMeta& rs_meta, int64_t sync_wait_t
     if (replicas.empty()) {
         VLOG_DEBUG << "There is no need to warmup tablet=" << rs_meta.tablet_id()
                    << ", skipping rowset=" << rs_meta.rowset_id().to_string();
+        g_file_cache_event_driven_warm_up_skipped_rowset_num << 1;
         return;
     }
     Status st = _do_warm_up_rowset(rs_meta, replicas, sync_wait_timeout_ms, !cache_hit);
