@@ -121,6 +121,7 @@ CONF_mBool(enable_mow_job_key_check, "false");
 CONF_mBool(enable_restore_job_check, "false");
 
 CONF_mBool(enable_tablet_stats_key_check, "false");
+CONF_mBool(enable_txn_key_check, "false");
 
 CONF_mBool(enable_checker_for_meta_key_check, "false");
 CONF_mInt64(mow_job_key_check_expiration_diff_seconds, "600"); // 10min
@@ -347,4 +348,7 @@ CONF_mString(ca_cert_file_paths,
 CONF_Bool(enable_check_fe_drop_in_safe_time, "true");
 CONF_mBool(enable_logging_conflict_keys, "false");
 
+CONF_mString(aws_credentials_provider_version, "v2");
+CONF_Validator(aws_credentials_provider_version,
+               [](const std::string& config) -> bool { return config == "v1" || config == "v2"; });
 } // namespace doris::cloud::config
