@@ -47,6 +47,22 @@ bvar::LatencyRecorder g_skip_cache_num("cached_remote_reader_skip_cache_num");
 bvar::Adder<uint64_t> g_skip_cache_sum("cached_remote_reader_skip_cache_sum");
 bvar::Adder<uint64_t> g_skip_local_cache_io_sum_bytes(
         "cached_remote_reader_skip_local_cache_io_sum_bytes");
+bvar::Adder<uint64_t> g_read_cache_direct_whole_num("cached_remote_reader_cache_direct_whole_num");
+bvar::Adder<uint64_t> g_read_cache_direct_partial_num(
+        "cached_remote_reader_cache_direct_partial_num");
+bvar::Adder<uint64_t> g_read_cache_indirect_num("cached_remote_reader_cache_indirect_num");
+bvar::Adder<uint64_t> g_read_cache_direct_whole_bytes(
+        "cached_remote_reader_cache_direct_whole_bytes");
+bvar::Adder<uint64_t> g_read_cache_direct_partial_bytes(
+        "cached_remote_reader_cache_direct_partial_bytes");
+bvar::Adder<uint64_t> g_read_cache_indirect_bytes("cached_remote_reader_cache_indirect_bytes");
+bvar::Adder<uint64_t> g_read_cache_indirect_total_bytes(
+        "cached_remote_reader_cache_indirect_total_bytes");
+bvar::Window<bvar::Adder<uint64_t>> g_read_cache_indirect_bytes_1min_window(
+        "cached_remote_reader_indirect_bytes_1min_window", &g_read_cache_indirect_bytes, 60);
+bvar::Window<bvar::Adder<uint64_t>> g_read_cache_indirect_total_bytes_1min_window(
+        "cached_remote_reader_indirect_total_bytes_1min_window", &g_read_cache_indirect_total_bytes,
+        60);
 
 CachedRemoteFileReader::CachedRemoteFileReader(FileReaderSPtr remote_file_reader,
                                                const FileReaderOptions& opts)
@@ -56,6 +72,7 @@ CachedRemoteFileReader::CachedRemoteFileReader(FileReaderSPtr remote_file_reader
         _cache_hash = BlockFileCache::hash(path().filename().native());
         _cache = FileCacheFactory::instance()->get_by_path(_cache_hash);
         if (config::enable_read_cache_file_directly) {
+            // this is designed for and test in doris table, external table need extra tests
             _cache_file_readers = _cache->get_blocks_by_key(_cache_hash);
         }
     } else {
@@ -78,14 +95,18 @@ CachedRemoteFileReader::CachedRemoteFileReader(FileReaderSPtr remote_file_reader
 }
 
 void CachedRemoteFileReader::_insert_file_reader(FileBlockSPtr file_block) {
-    if (config::enable_read_cache_file_directly) {
+    if (_is_doris_table && config::enable_read_cache_file_directly) {
         std::lock_guard lock(_mtx);
         DCHECK(file_block->state() == FileBlock::State::DOWNLOADED);
+        file_block->_owned_by_cached_reader = true;
         _cache_file_readers.emplace(file_block->offset(), std::move(file_block));
     }
 }
 
 CachedRemoteFileReader::~CachedRemoteFileReader() {
+    for (auto& it : _cache_file_readers) {
+        it.second->_owned_by_cached_reader = false;
+    }
     static_cast<void>(close());
 }
 
@@ -112,6 +133,7 @@ std::pair<size_t, size_t> CachedRemoteFileReader::s_align_size(size_t offset, si
 
 Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t* bytes_read,
                                             const IOContext* io_ctx) {
+    size_t already_read = 0;
     const bool is_dryrun = io_ctx->is_dryrun;
     DCHECK(!closed());
     DCHECK(io_ctx);
@@ -127,7 +149,21 @@ Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t*
         return Status::OK();
     }
     ReadStatistics stats;
+    MonotonicStopWatch read_at_sw;
+    read_at_sw.start();
     auto defer_func = [&](int*) {
+        if (config::print_stack_when_cache_miss) {
+            if (io_ctx->file_cache_stats == nullptr && !stats.hit_cache && !io_ctx->is_warmup) {
+                LOG_INFO("[verbose] {}", Status::InternalError<true>("not hit cache"));
+            }
+        }
+        if (!stats.hit_cache && config::read_cluster_cache_opt_verbose_log) {
+            LOG_INFO(
+                    "[verbose] not hit cache, path: {}, offset: {}, size: {}, cost: {} ms, warmup: "
+                    "{}",
+                    path().native(), offset, bytes_req, read_at_sw.elapsed_time_milliseconds(),
+                    io_ctx->is_warmup);
+        }
         if (io_ctx->file_cache_stats && !is_dryrun) {
             // update stats in io_ctx, for query profile
             _update_stats(stats, io_ctx->file_cache_stats, io_ctx->is_inverted_index);
@@ -139,7 +175,7 @@ Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t*
     };
     std::unique_ptr<int, decltype(defer_func)> defer((int*)0x01, std::move(defer_func));
     stats.bytes_read += bytes_req;
-    if (config::enable_read_cache_file_directly) {
+    if (_is_doris_table && config::enable_read_cache_file_directly) {
         // read directly
         SCOPED_RAW_TIMER(&stats.read_cache_file_directly_timer);
         size_t need_read_size = bytes_req;
@@ -166,23 +202,33 @@ Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t*
                     if (!iter->second
                                  ->read(Slice(result.data + (cur_offset - offset), reserve_bytes),
                                         file_offset)
-                                 .ok()) {
+                                 .ok()) { //TODO: maybe read failed because block evict, should handle error
                         break;
                     }
                 }
+                _cache->add_need_update_lru_block(iter->second);
                 need_read_size -= reserve_bytes;
                 cur_offset += reserve_bytes;
+                already_read += reserve_bytes;
                 iter++;
             }
             if (need_read_size == 0) {
                 *bytes_read = bytes_req;
                 stats.hit_cache = true;
+                g_read_cache_direct_whole_num << 1;
+                g_read_cache_direct_whole_bytes << bytes_req;
                 return Status::OK();
+            } else {
+                g_read_cache_direct_partial_num << 1;
+                g_read_cache_direct_partial_bytes << already_read;
             }
         }
     }
     // read from cache or remote
-    auto [align_left, align_size] = s_align_size(offset, bytes_req, size());
+    g_read_cache_indirect_num << 1;
+    size_t indirect_read_bytes = 0;
+    auto [align_left, align_size] =
+            s_align_size(offset + already_read, bytes_req - already_read, size());
     CacheContext cache_context(io_ctx);
     cache_context.stats = &stats;
     MonotonicStopWatch sw;
@@ -210,6 +256,7 @@ Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t*
             stats.hit_cache = false;
             break;
         case FileBlock::State::DOWNLOADED:
+            _insert_file_reader(block);
             break;
         }
     }
@@ -246,13 +293,14 @@ Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t*
         }
         // copy from memory directly
         size_t right_offset = offset + bytes_req - 1;
-        if (empty_start <= right_offset && empty_end >= offset && !is_dryrun) {
-            size_t copy_left_offset = offset < empty_start ? empty_start : offset;
-            size_t copy_right_offset = right_offset < empty_end ? right_offset : empty_end;
+        if (empty_start <= right_offset && empty_end >= offset + already_read && !is_dryrun) {
+            size_t copy_left_offset = std::max(offset + already_read, empty_start);
+            size_t copy_right_offset = std::min(right_offset, empty_end);
             char* dst = result.data + (copy_left_offset - offset);
             char* src = buffer.get() + (copy_left_offset - empty_start);
             size_t copy_size = copy_right_offset - copy_left_offset + 1;
             memcpy(dst, src, copy_size);
+            indirect_read_bytes += copy_size;
         }
     }
 
@@ -307,6 +355,7 @@ Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t*
                     SCOPED_RAW_TIMER(&stats.local_read_timer);
                     st = block->read(Slice(result.data + (current_offset - offset), read_size),
                                      file_offset);
+                    indirect_read_bytes += read_size;
                 }
             }
             if (!st || block_state != FileBlock::State::DOWNLOADED) {
@@ -319,12 +368,16 @@ Status CachedRemoteFileReader::read_at_impl(size_t offset, Slice result, size_t*
                 RETURN_IF_ERROR(_remote_file_reader->read_at(
                         current_offset, Slice(result.data + (current_offset - offset), read_size),
                         &bytes_read));
+                indirect_read_bytes += read_size;
                 DCHECK(bytes_read == read_size);
             }
         }
         *bytes_read += read_size;
         current_offset = right + 1;
     }
+    g_read_cache_indirect_bytes << indirect_read_bytes;
+    g_read_cache_indirect_total_bytes << *bytes_read;
+
     DCHECK(*bytes_read == bytes_req);
     return Status::OK();
 }
