@@ -1317,6 +1317,17 @@ Status VFileScanner::_get_next_reader() {
             _slot_lower_name_to_col_type.emplace(to_lower(col_name), col_type);
         }
 
+        if (!_fill_partition_from_path && config::enable_iceberg_partition_column_fallback) {
+            // check if the cols of _partition_col_descs are in _missing_cols
+            // if so, set _fill_partition_from_path to true and remove the col from _missing_cols
+            for (const auto& [col_name, col_type] : _partition_col_descs) {
+                if (_missing_cols.contains(col_name)) {
+                    _fill_partition_from_path = true;
+                    _missing_cols.erase(col_name);
+                }
+            }
+        }
+
         RETURN_IF_ERROR(_generate_missing_columns());
         if (_fill_partition_from_path) {
             RETURN_IF_ERROR(
