@@ -23,6 +23,7 @@
 
 #include <memory>
 
+#include "cloud/cloud_base_compaction.h"
 #include "cloud/cloud_cluster_info.h"
 #include "cloud/cloud_storage_engine.h"
 #include "cloud/cloud_tablet.h"
@@ -385,4 +386,48 @@ TEST_F(CloudCompactionTest, test_set_storage_resource_from_input_rowsets) {
         ASSERT_FALSE(ctx.storage_resource.has_value());
     }
 }
+TEST_F(CloudCompactionTest, should_cache_compaction_output) {
+    CloudTabletSPtr tablet = std::make_shared<CloudTablet>(_engine, std::make_shared<TabletMeta>());
+    CloudBaseCompaction cloud_base_compaction(_engine, tablet);
+    cloud_base_compaction._input_rowsets_total_size = 0;
+    cloud_base_compaction._input_rowsets_cached_data_size = 0;
+    cloud_base_compaction._input_rowsets_cached_index_size = 0;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), false);
+
+    cloud_base_compaction._input_rowsets_total_size = 100;
+    cloud_base_compaction._input_rowsets_cached_data_size = 0;
+    cloud_base_compaction._input_rowsets_cached_index_size = 0;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), false);
+
+    cloud_base_compaction._input_rowsets_total_size = 100;
+    cloud_base_compaction._input_rowsets_cached_data_size = 70;
+    cloud_base_compaction._input_rowsets_cached_index_size = 0;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), false);
+
+    cloud_base_compaction._input_rowsets_total_size = 100;
+    cloud_base_compaction._input_rowsets_cached_data_size = 0;
+    cloud_base_compaction._input_rowsets_cached_index_size = 70;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), false);
+
+    cloud_base_compaction._input_rowsets_total_size = 100;
+    cloud_base_compaction._input_rowsets_cached_data_size = 0;
+    cloud_base_compaction._input_rowsets_cached_index_size = 70;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), false);
+
+    cloud_base_compaction._input_rowsets_total_size = 100;
+    cloud_base_compaction._input_rowsets_cached_data_size = 80;
+    cloud_base_compaction._input_rowsets_cached_index_size = 0;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), true);
+
+    cloud_base_compaction._input_rowsets_total_size = 100;
+    cloud_base_compaction._input_rowsets_cached_data_size = 0;
+    cloud_base_compaction._input_rowsets_cached_index_size = 80;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), true);
+
+    cloud_base_compaction._input_rowsets_total_size = 100;
+    cloud_base_compaction._input_rowsets_cached_data_size = 50;
+    cloud_base_compaction._input_rowsets_cached_index_size = 50;
+    ASSERT_EQ(cloud_base_compaction.should_cache_compaction_output(), true);
+    LOG(INFO) << "should_cache_compaction_output done";
+}
 } // namespace doris
